@@ -7,4 +7,4 @@ from .models.lr_scheduler import LinearDownLR
 from .utils.dist_util import master_only, get_rank
 from .metrics  import *
 
-name = "torch_helper"
\ No newline at end of file
+name = "torchelper"
\ No newline at end of file
